import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ios_device_check/ios_device_check.dart';

void main() => runApp(new MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => new _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _token = 'Unknown';

  @override
  initState() {
    super.initState();
    _generateToken();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  _generateToken() async {
    String token;

    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      token = await IosDeviceCheck.generateToken();
    } on PlatformException {
      token = 'Failed to generateToken.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted)
      return;

    setState(() {
      _token = token;
    });
  }

  @override
  Widget build(BuildContext context) {
    return new MaterialApp(
      home: new Scaffold(
        appBar: new AppBar(
          title: new Text('DeviceCheck Plugin Example'),
        ),
        body: new SingleChildScrollView(
          padding: new EdgeInsets.all(10.0),
          child: new Text(_token),
        ),
        floatingActionButton: new FloatingActionButton(
          onPressed: _generateToken,
          child: new Icon(Icons.refresh)
        ),
      ),
    );
  }
}
